@@ -1,6 +1,6 @@
 /*
  * OctoMap - An Efficient Probabilistic 3D Mapping Framework Based on Octrees
- * http://octomap.github.com/
+ * https://octomap.github.io/
  *
  * Copyright (c) 2009-2013, K.M. Wurm and A. Hornung, University of Freiburg
  * All rights reserved.
@@ -37,6 +37,7 @@
 #include <stdio.h>
 #include <vector>
 #include <list>
+#include <inttypes.h>
 
 #include <octomap/math/Vector3.h>
 #include <octomap/math/Pose6D.h>
