@@ -10,7 +10,7 @@ using namespace octomath;
 
 
 
-int main(int argc, char** argv) {
+int main(int /*argc*/, char** /*argv*/) {
 
 
 
